import infra.basetest


class TestATFAllwinner(infra.basetest.BRTest):
    config = \
        """
        BR2_aarch64=y
        BR2_TOOLCHAIN_EXTERNAL=y
        BR2_TOOLCHAIN_EXTERNAL_ARM_AARCH64=y
        BR2_TARGET_ARM_TRUSTED_FIRMWARE=y
        BR2_TARGET_ARM_TRUSTED_FIRMWARE_CUSTOM_VERSION=y
        BR2_TARGET_ARM_TRUSTED_FIRMWARE_CUSTOM_VERSION_VALUE="v2.11"
        BR2_TARGET_ARM_TRUSTED_FIRMWARE_PLATFORM="sun50i_a64"
        # BR2_TARGET_ARM_TRUSTED_FIRMWARE_SSP is not set
        BR2_TARGET_ARM_TRUSTED_FIRMWARE_BL31=y
        BR2_TARGET_UBOOT=y
        BR2_TARGET_UBOOT_BUILD_SYSTEM_KCONFIG=y
        BR2_TARGET_UBOOT_CUSTOM_VERSION=y
        BR2_TARGET_UBOOT_CUSTOM_VERSION_VALUE="2023.10"
        BR2_TARGET_UBOOT_BOARD_DEFCONFIG="orangepi_zero_plus2"
        BR2_TARGET_UBOOT_NEEDS_DTC=y
        BR2_TARGET_UBOOT_NEEDS_OPENSSL=y
        BR2_TARGET_UBOOT_NEEDS_PYTHON3=y
        BR2_TARGET_UBOOT_NEEDS_PYLIBFDT=y
        BR2_TARGET_UBOOT_NEEDS_ATF_BL31=y
        BR2_TARGET_UBOOT_SPL=y
        BR2_TARGET_UBOOT_SPL_NAME="u-boot-sunxi-with-spl.bin"
        BR2_TARGET_UBOOT_CUSTOM_MAKEOPTS="SCP=/dev/null"
        """

    def test_run(self):
        pass
